<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FontsDialog</name>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="28"/>
        <source>LabelsFont</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="31"/>
        <location filename="../../src/FontsDialog.cpp" line="51"/>
        <source>ResetDefaultValue</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="48"/>
        <source>FieldsFont</source>
        <translation>フィールド</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="63"/>
        <source>LanguageFontOverrides</source>
        <translation>言語のフォントのオーバーライト</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="73"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="89"/>
        <source>Fonts Settings</source>
        <translation>フォント</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="8"/>
        <source>Home</source>
        <translation>ホーム</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="9"/>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="30"/>
        <source>Help: %1</source>
        <translation>ヘルプ：　%1</translation>
    </message>
</context>
<context>
    <name>KeyboardAcceleratorsDialog</name>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Action</source>
        <translation>機能</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Key</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="43"/>
        <source>Clear key</source>
        <translation>消す</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="44"/>
        <source>Set key</source>
        <translation>指定</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="45"/>
        <source>Reset key</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="63"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="87"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>キーボードショートカット</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="122"/>
        <source>&lt;press key&gt;</source>
        <translation>ショートカットを打って下さい</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="190"/>
        <source>Duplicate key binding</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>Key &apos;</source>
        <translation>キー　&apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>&apos;
is currently assigned to
&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="192"/>
        <source>&apos;.
Overwrite the current assignment?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/MainWindow.cpp" line="60"/>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <location filename="../../src/MainWindow.cpp" line="217"/>
        <source>StartQuiz</source>
        <translation>クイズを始める</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="62"/>
        <location filename="../../src/MainWindow.cpp" line="218"/>
        <source>ManageGlossaries</source>
        <translation>用語集を管理する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="64"/>
        <location filename="../../src/MainWindow.cpp" line="219"/>
        <source>Import...</source>
        <translation>インポート</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="66"/>
        <location filename="../../src/MainWindow.cpp" line="220"/>
        <source>Export...</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="70"/>
        <location filename="../../src/MainWindow.cpp" line="222"/>
        <source>Preferences...</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="72"/>
        <location filename="../../src/MainWindow.cpp" line="223"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="68"/>
        <location filename="../../src/MainWindow.cpp" line="221"/>
        <source>ShowAllGlossariesAndTerms</source>
        <translation>全ての用語集と言葉を表示する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="132"/>
        <location filename="../../src/MainWindow.cpp" line="236"/>
        <source>About...</source>
        <translation>toMOTkoについて</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <source>RestartQuiz</source>
        <translation>クイズを再び始める</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutToMOTko...</source>
        <translation>toMOTkoについて...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutMessage</source>
        <translation>&lt;html&gt;&lt;h2&gt;toMOTko v0.11.2&lt;/h2&gt;&lt;p&gt;外国語を勉強するためのアプリケーション&lt;/p&gt;&lt;p&gt;作成者：Frederic Bergeron&lt;br/&gt;(&lt;a href=&quot;mailto:fbergeron@users.sourceforge.net&quot;&gt;fbergeron@users.sourceforge.net&lt;/a&gt;)&lt;br/&gt;(c) 2006-2009&lt;/p&gt;&lt;p&gt;使用許可：GPL v2.&lt;/p&gt;&lt;p&gt;詳しくは:&lt;br/&gt;&lt;a href=&quot;http://tomotko.sourceforge.net&quot;&gt;http://tomotko.sourceforge.net&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="52"/>
        <location filename="../../src/MainWindow.cpp" line="213"/>
        <source>Reveal</source>
        <translation>表す</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="54"/>
        <location filename="../../src/MainWindow.cpp" line="214"/>
        <source>RightAnswer</source>
        <translation>正解</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="56"/>
        <location filename="../../src/MainWindow.cpp" line="215"/>
        <source>WrongAnswer</source>
        <translation>不正解</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="58"/>
        <location filename="../../src/MainWindow.cpp" line="216"/>
        <source>EditQuizTerm</source>
        <translation>クイズの言葉を編集する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="74"/>
        <location filename="../../src/MainWindow.cpp" line="224"/>
        <source>AddFolder</source>
        <translation>新しいフォルダーを作る</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="76"/>
        <location filename="../../src/MainWindow.cpp" line="225"/>
        <source>AddGlossary</source>
        <translation>新しい用語集を作る</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="78"/>
        <location filename="../../src/MainWindow.cpp" line="226"/>
        <source>RemoveItem</source>
        <translation>項目を削除する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="80"/>
        <location filename="../../src/MainWindow.cpp" line="227"/>
        <source>AddTerm</source>
        <translation>言葉を追加する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="82"/>
        <location filename="../../src/MainWindow.cpp" line="228"/>
        <source>EditTerm</source>
        <translation>言葉を編集する</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="84"/>
        <location filename="../../src/MainWindow.cpp" line="229"/>
        <source>RemoveTerm</source>
        <translation>言葉を消す</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="86"/>
        <location filename="../../src/MainWindow.cpp" line="230"/>
        <source>CheckAllTerms</source>
        <translation>全ての言葉にチェックを入れる</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="304"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="305"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <source>NoTermsMarkedForStudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <source>TermsMissing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="88"/>
        <location filename="../../src/MainWindow.cpp" line="231"/>
        <source>InverseCheckedTerms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="90"/>
        <location filename="../../src/MainWindow.cpp" line="232"/>
        <source>Maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="92"/>
        <location filename="../../src/MainWindow.cpp" line="233"/>
        <source>Search...</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="130"/>
        <location filename="../../src/MainWindow.cpp" line="235"/>
        <source>Help...</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <source>ConfirmResumeQuiz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="134"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>キーボードショートカット...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="34"/>
        <source>Length</source>
        <translation>質問の数</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="54"/>
        <source>QuizLengthShortest</source>
        <translation>少ない (1)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="55"/>
        <source>QuizLengthMedium</source>
        <translation>普通 (3)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="57"/>
        <source>QuizLengthLongest</source>
        <translation>多い (5)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="73"/>
        <source>DigraphesEnabled</source>
        <translation>ダイグラフをオン</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="189"/>
        <source>Preferences...</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="76"/>
        <source>hideQuizButtons</source>
        <translation>クイズのボタンを隠す</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="79"/>
        <source>ShowAltInTermList</source>
        <translation>発音を表示する</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="87"/>
        <source>InterfaceLanguage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="137"/>
        <source>Study Language Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="140"/>
        <source>Fonts Settings</source>
        <translation>フォント...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="143"/>
        <source>Revealing Sequences Settings</source>
        <translation>表示順番...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="151"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>PropertiesPanel</name>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="59"/>
        <location filename="../../src/PropertiesPanel.cpp" line="92"/>
        <source>Words</source>
        <translation>言葉</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="99"/>
        <source>Glossaries</source>
        <translation>用語集</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="106"/>
        <source>Folders</source>
        <translation>フォルダー</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Selected</source>
        <translation>クイズ</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Checked</source>
        <translation>チェック</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="133"/>
        <location filename="../../src/PropertiesPanel.cpp" line="279"/>
        <source>Description</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="127"/>
        <location filename="../../src/PropertiesPanel.cpp" line="284"/>
        <source>Title</source>
        <translation>題名</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="137"/>
        <location filename="../../src/PropertiesPanel.cpp" line="280"/>
        <source>Content</source>
        <translation>内容</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Items</source>
        <translation>項目</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Total</source>
        <translation>合計</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="169"/>
        <location filename="../../src/PropertiesPanel.cpp" line="285"/>
        <source>Author</source>
        <translation>作成者</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="175"/>
        <location filename="../../src/PropertiesPanel.cpp" line="286"/>
        <source>CreationDate</source>
        <translation>作成日時</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="181"/>
        <location filename="../../src/PropertiesPanel.cpp" line="287"/>
        <source>ModificationDate</source>
        <translation>更新日時</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>en</source>
        <translation>英語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>fr</source>
        <translation>フランス語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>es</source>
        <translation>スペイン語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>ja</source>
        <translation>日本語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>de</source>
        <translation>ドイツ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>ar</source>
        <translation>アラビア語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>bg</source>
        <translation>ブルガリア語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>el</source>
        <translation>ギリシャ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>cs</source>
        <translation>チェコ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>da</source>
        <translation>デンマーク語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>it</source>
        <translation>イタリア語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>eo</source>
        <translation>エスペラント</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>fi</source>
        <translation>フィンランド</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>he</source>
        <translation>ヘブライ</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hi</source>
        <translation>ヒンディー</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hu</source>
        <translation>ハンガリー語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>ko</source>
        <translation>韓国語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>nl</source>
        <translation>オランダ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>pt</source>
        <translation>ポルトガル語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>la</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>rm</source>
        <translation>ロマンシュ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ru</source>
        <translation>ロシア語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sw</source>
        <translation>スワヒリ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>th</source>
        <translation>タイ語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ro</source>
        <translation>ルーマニア語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sv</source>
        <translation>スウェーデン</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>vi</source>
        <translation>ベトナム語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>zh</source>
        <translation>中国語</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>tl</source>
        <translation>タガログ</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="40"/>
        <source>Cut</source>
        <translation>切り取り</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="39"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="41"/>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="46"/>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <location filename="../../src/VocabParser.cpp" line="85"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>Warning</source>
        <translation>注意</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="737"/>
        <source>MyGlossaries</source>
        <translation>私の用語集</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="144"/>
        <source>NewFolder</source>
        <translation>新しいフォルダーを作る</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="173"/>
        <source>NewGlossary</source>
        <translation>新しい用語集を作る</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <source>ErrorSavingData</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ResultListItem.cpp" line="20"/>
        <location filename="../../src/ResultListItem.cpp" line="33"/>
        <location filename="../../src/TermListItem.cpp" line="23"/>
        <location filename="../../src/TermListItem.cpp" line="36"/>
        <source>Undefined</source>
        <translation>未定義</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="408"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>OperationSuccessful</source>
        <translation>作業終了</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>OperationFailed</source>
        <translation>作業できませんでした</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="47"/>
        <location filename="../../src/VocabParser.cpp" line="86"/>
        <source>ParseError</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuizFrame</name>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="99"/>
        <location filename="../../src/QuizFrame.cpp" line="128"/>
        <location filename="../../src/QuizFrame.cpp" line="635"/>
        <location filename="../../src/QuizFrame.cpp" line="638"/>
        <source>Word/Expr.</source>
        <translation>言葉</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="104"/>
        <location filename="../../src/QuizFrame.cpp" line="139"/>
        <location filename="../../src/QuizFrame.cpp" line="149"/>
        <location filename="../../src/QuizFrame.cpp" line="187"/>
        <location filename="../../src/QuizFrame.cpp" line="202"/>
        <location filename="../../src/QuizFrame.cpp" line="636"/>
        <location filename="../../src/QuizFrame.cpp" line="639"/>
        <location filename="../../src/QuizFrame.cpp" line="640"/>
        <location filename="../../src/QuizFrame.cpp" line="643"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="126"/>
        <location filename="../../src/QuizFrame.cpp" line="637"/>
        <source>Alt./Phon.</source>
        <translation>発音</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="169"/>
        <location filename="../../src/QuizFrame.cpp" line="642"/>
        <source>Examples/Comments</source>
        <translation>例/コメント</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <source>WellDone</source>
        <translation>おめでとう！全ての%1の言葉を習いました。用語集マネジャーで違う言葉を選択して下さい。</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="197"/>
        <location filename="../../src/QuizFrame.cpp" line="641"/>
        <source>Image</source>
        <translation>イメージ</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>DissociatedWord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Glossary</source>
        <translation>用語集</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="294"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="295"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="47"/>
        <location filename="../../src/SearchDialog.cpp" line="169"/>
        <source>Results</source>
        <translation>結果</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Location</source>
        <translation>場所</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="72"/>
        <location filename="../../src/SearchDialog.cpp" line="176"/>
        <source>View Glossary</source>
        <translation>用語集を見る</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="77"/>
        <location filename="../../src/SearchDialog.cpp" line="178"/>
        <source>Edit Term</source>
        <translation>言葉を編集する</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="82"/>
        <location filename="../../src/SearchDialog.cpp" line="180"/>
        <source>Remove Term(s)</source>
        <translation>言葉を削除する</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="88"/>
        <location filename="../../src/SearchDialog.cpp" line="182"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="113"/>
        <location filename="../../src/SearchDialog.cpp" line="187"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="170"/>
        <location filename="../../src/SearchDialog.cpp" line="208"/>
        <source>%1 term(s) found</source>
        <translation>%1個の言葉が見つかりました。</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>本当にこれを削除してもいいですか？</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SequenceDialog</name>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="22"/>
        <source>Quiz</source>
        <translation>クイズ</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="56"/>
        <location filename="../../src/SequenceDialog.cpp" line="88"/>
        <source>Word/Expr.</source>
        <translation>言葉</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="86"/>
        <source>Alt./Phon.</source>
        <translation>発音</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="52"/>
        <source>FirstLanguage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="72"/>
        <source>TestLanguage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="102"/>
        <source>Image</source>
        <translation>イメージ</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="115"/>
        <source>CommentLabelPanel</source>
        <translation>例/コメント</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="128"/>
        <source>Sequence</source>
        <translation>表示順番</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="166"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="168"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="191"/>
        <source>AddRevealingSequence</source>
        <translation>新しい順番を加える</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <source>SequenceNotTerminated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <source>SequenceIsEmpty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SequencesDialog</name>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="23"/>
        <source>Existing Sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="47"/>
        <source>QuizWindow</source>
        <translation>クイズのウィンドウ</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="62"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="78"/>
        <source>RevealingOrders</source>
        <translation>表示順番</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <source>RevealingOrderMandatory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StudyLanguagesDialog</name>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="26"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="45"/>
        <source>Study Language Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <source>StudyLanguagesMandatory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TermDialog</name>
    <message>
        <location filename="../../src/TermDialog.cpp" line="62"/>
        <location filename="../../src/TermDialog.cpp" line="84"/>
        <source>Word/Expr.</source>
        <translation>言葉</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="82"/>
        <source>Alt./Phon.</source>
        <translation>発音</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="109"/>
        <source>Examples/Comments</source>
        <translation>例/コメント</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="167"/>
        <source>EditTerm</source>
        <translation>言葉を編集する</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="137"/>
        <source>Image</source>
        <translation>イメージ</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="128"/>
        <source>setImage</source>
        <translation>指定</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="132"/>
        <source>clearImage</source>
        <translation>消す</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="148"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="150"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>SetImage...</source>
        <translation>イメージを指定する ...</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>Images (*.png *.gif)</source>
        <translation>イメージ (*.png *.gif)</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <source>CannotReadImage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TranslationSelectionDialog</name>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="15"/>
        <source>Languages</source>
        <translation>言語</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="37"/>
        <source>CheckAllLanguages</source>
        <translation>全ての言語にチェックを入れる</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="45"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <location filename="../../src/Util.cpp" line="22"/>
        <source>VerySmall</source>
        <translation>とても小さい</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="23"/>
        <source>Small</source>
        <translation>小さい</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="24"/>
        <source>Medium</source>
        <translation>普通</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="25"/>
        <source>Large</source>
        <translation>大きい</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="26"/>
        <source>VeryLarge</source>
        <translation>とても大きい</translation>
    </message>
</context>
<context>
    <name>VocabularyManagerFrame</name>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="46"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="596"/>
        <source>Glossaries</source>
        <translation>用語集</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="839"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="973"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="840"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="974"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="186"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="604"/>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="187"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="605"/>
        <source>Words</source>
        <translation>言葉</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>Import...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="453"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="479"/>
        <source>Export...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <source>ConfirmRemoveItem</source>
        <translation>本当にこれを削除してもいいですか？</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>本当にこれを削除してもいいですか？</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="454"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="480"/>
        <source>Glossaries (*.zip)</source>
        <translation>用語集 (*.zip)</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>MultipleTranslationsDetectedForImport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="405"/>
        <source>ImportSuccessful</source>
        <translation>インポートができました</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="407"/>
        <source>InvisibleImport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <source>ItemImportFailed</source>
        <translation>インポートができませんでした</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <source>ItemImportFailedZipFileExpected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <source>MultipleTranslationsDetectedForExport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <source>GlossaryExportSuccessful</source>
        <translation>エクスポートができました</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <source>GlossaryExportFailed</source>
        <translation>エクスポートができませんでした</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <source>MultipleTranslationsDetectedForFolderExport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>FolderExportSuccessful</source>
        <translation>エクスポートができました</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>FolderExportFailed</source>
        <translation>エクスポートができませんでした</translation>
    </message>
</context>
</TS>
